#ifndef SEALEDPAD_FRAME_H
#define SEALEDPAD_FRAME_H

class wxFindDialogEvent;
class wxFindReplaceData;
class wxFindReplaceDialog;


class MyFrame: public wxFrame
{
public:
    MyFrame();
    virtual ~MyFrame();
    virtual bool Show(bool show=true);
    
    wxString GetFileName() const;
    void SetFileName(const wxString &filename, const wxString &password);
    void FindUI(bool replace=FALSE);
    bool FindForward(const wxString& find);
    bool FindBackward(const wxString& find);
    bool FindNext();
    void FindNextUI();
    void ReplaceAll(const wxString& find, const wxString& replace);
    void UpdateStatusBar();
    bool Load(const wxString& filename, const wxString& password);
    bool LoadUI(const wxString& filename);
    bool GetWrap() const;
    void SetWrap(bool wrap);
    void ShowStatusBar(bool show=TRUE);
    void UpdateClientWindows();
    
    void SaveConfig();
    void LoadConfig();
    
    void New();
    bool OpenUI();
    bool Save();
    bool SaveUI();
    bool SaveAs(const wxString& filename, const wxString& password);
    bool SaveAsUI();
    bool AskSaveUI();
    bool Delete();
    
    void OnClose(wxCloseEvent& event);
    
    void OnNew(wxCommandEvent &event);
    void OnOpen(wxCommandEvent &event);
    void OnSave(wxCommandEvent &event);
    void OnSaveAs(wxCommandEvent &event);
    void OnQuit(wxCommandEvent &event);
    
    void OnUndo(wxCommandEvent &event);
    void OnCut(wxCommandEvent &event);
    void OnCopy(wxCommandEvent &event);
    void OnPaste(wxCommandEvent &event);
    void OnDelete(wxCommandEvent &event);
    void OnFind(wxCommandEvent &event);
    void OnFindNext(wxCommandEvent &event);
    void OnReplace(wxCommandEvent &event);
    void OnJump(wxCommandEvent &event);
    void OnSelectAll(wxCommandEvent &event);
    void OnInsertDate(wxCommandEvent &event);
    
    void OnWrap(wxCommandEvent &event);
    void OnFont(wxCommandEvent &event);
    
    void OnStatusBar(wxCommandEvent &event);
    
    void OnAbout(wxCommandEvent &event);
    
    
    void OnUpdateUndo(wxUpdateUIEvent &event);
    void OnUpdateCut(wxUpdateUIEvent &event);
    void OnUpdateCopy(wxUpdateUIEvent &event);
    void OnUpdatePaste(wxUpdateUIEvent &event);
    void OnUpdateDelete(wxUpdateUIEvent &event);
    void OnUpdateFind(wxUpdateUIEvent &event);
    void OnUpdateFindNext(wxUpdateUIEvent &event);
    
    void OnUpdateWrap(wxUpdateUIEvent &event);
    void OnUpdateStatusBar(wxUpdateUIEvent &event);
    
    void OnFindFind(wxFindDialogEvent &event);
    void OnFindReplace(wxFindDialogEvent &event);
    void OnFindReplaceAll(wxFindDialogEvent &event);
    void OnFindClose(wxFindDialogEvent &event);
    
    
    void OnText(wxCommandEvent &event);
    
    void OnDropFiles(wxDropFilesEvent &event);
    
    DECLARE_EVENT_TABLE()
    
private:
    wxString _filename;
    wxString _password;
    wxString _datetime_format;
    wxString _statusbar_format;
    wxTextCtrl *_textctrl;
    wxFindReplaceData *_finddata;
    wxFindReplaceDialog *_finddlg;
    bool _statusbar;
};


class TextCtrlWatcher: public wxEvtHandler
{
public:
    TextCtrlWatcher(MyFrame *parent);
    
    void OnKey(wxKeyEvent &event);
    void OnMouse(wxMouseEvent &event);
    
    DECLARE_EVENT_TABLE()

private:
    MyFrame *_parent;
};


#endif
